#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 case-insensitive
version:              1.2.1.0
visibility:           public
id:                   case-insensitive-1.2.1.0-Hy8vIpMkQN812iirgNYqdk
key:                  case-insensitive-1.2.1.0-Hy8vIpMkQN812iirgNYqdk
license:              BSD-3-Clause
copyright:            2011 Bas van Dijk
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk
homepage:             https://github.com/basvandijk/case-insensitive
synopsis:             Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.

category:             Data, Text
abi:                  0af9a9b9347b2bc2535c52d357d1b278
exposed:              True
exposed-modules:      Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules:       Data.CaseInsensitive.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/case-insensitive-1.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/case-insensitive-1.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/case-insensitive-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-case-insensitive
hs-libraries:         HScase-insensitive-1.2.1.0-Hy8vIpMkQN812iirgNYqdk
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1
    hashable-1.4.7.0-Hz50npgMQxgKvfGaVdBop2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock

haddock-html:         /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

